progress_dialog — Camelot documentation

### Navigation

- index
- modules |
- next |
- previous |
- Camelot documentation »
- Camelot API »
- view »
- controls »

# progress_dialog

Functions and classes to use a progress dialog in combination with a model thread

class `camelot.view.controls.progress_dialog.` `ProgressDialog`(name, icon=Icon('tango/32x32/actions/appointment-new.png'))

  A Progress Dialog to be used in combination with a post to the model thread:

  to display a progress dialog until my_function has finished:

      d = ProgressDialog()
      post(my_function, d.finished, d.exception)
      d.exec_()

  `display_pixmap`(pixmap)

    Parameters: | image – a camelot.view.art.Pixmap object

  `exit`(return_code)

    Stop the application event loop, with the given return code

### Navigation

- index
- modules |
- next |
- previous |
- Camelot documentation »
- Camelot API »
- view »
- controls »

Comments
blog comments powered by Disqus